% code to convert soil water content to soil water potential.
% Clapp and Hornberger, 1978, WRR
% Adapted from LYY, 2020, NCC,
% https://github.com/YanlanLiu/model-data-fusion, myFun
function psis = ClappHornbergerswc(sand, silt, clay, th, calib) % sand, silt, clay are int. th is soil water conten, calib = 0.62 (LYY 2020 NCC)

BB = [4.05,4.38,4.90,5.3,5.39,7.12,7.75,8.52,10.4,10.4,11.4];
PSAT = [12.1,9.0,21.8,78.6,47.8,29.9,35.6,63.0,15.3,49,40.5]*1e-2*1e3*9.8*1e-6;
THETAS = [0.395,0.410,0.435,0.485,0.451,0.420,0.477,0.476,0.426,0.492,0.482];
KSAT = [1.056,0.938,0.208,0.0432,0.0417,0.0378,0.0102,0.0147,0.0130,0.0062,0.0077]*1e-2/60;


       if silt+1.5*clay<15 
            tx = 0; % sand
       elseif silt+1.5*clay>=15 & silt+2*clay<30 
            tx = 1; % loamy sand
       elseif (7<=clay & clay<20 & sand>52 & silt+2*clay>=30) | (clay<7 & silt<50 & silt+2*clay>=30)
            tx = 2; % sandy loam
       elseif (silt>=50 & 12<=clay & clay<27) | (50<=silt & silt<80 & clay<12)
            tx = 3; % silt loam
       elseif 7<=clay & clay<27 & 28<=silt & silt<50 & sand <=52
            tx = 4; % loam
       elseif 20<=clay & clay<35 & silt<28 & sand >45
            tx = 5; % sandy clay loam
       elseif 27<=clay & clay<40 & sand<=20
            tx = 6; % silt clay loam
       elseif 27<=clay & clay<40 & 20<sand & sand<=45
            tx = 7; % clay loam
       elseif clay>=35 & sand>45
            tx = 8; % sandy clay
       elseif clay>=40 & silt>=40
            tx = 9; % silt clay
       elseif clay>=40 & sand<=45 & silt<40
            tx = 10; % clay  
       elseif silt>=80 & clay<12
            tx = 3; % silt
       else
            tx = NaN;
       end
       
       tx = tx + 1; % start from 1
    
    if ~isnan(tx)
    
        b = BB(tx)*calib;
        ssat = THETAS(tx);
        
        %th = rswc*ssat; % added by Luo
        
        s = min(max(th/ssat,0),1);
        psis = PSAT(tx)*(s)^(-b);
        k = KSAT(tx)*(s)^(2*b+3);
        sfc = (-0.01/PSAT(tx))^(-1/b)*ssat;
        sw = (-3/PSAT(tx))^(-1/b)*ssat;
        sh = (-10/PSAT(tx))^(-1/b)*ssat;
        %return k,psis,ssat,b,sfc,sw,sh
    
    else
        psis = NaN;
        %th = NaN;
        
    end
end